
#
# Create a catalog of stars which fall on each quadrant of the
#   eastern block of detectors.  Place stars of a wide range of
#   spectral types into each quadrant.  
#
# One can run the "refcat" procedure on this catalog to make
#   an input file for the pipeline.
#
#
# MWR 9/3/2003

set debug 1


proc sptype_to_bminusr { sptype } {


  if { [string compare $sptype "o5v"] == 0 } { return { 14.288 15.000  } }
  if { [string compare $sptype "b57v"] == 0 } { return { 14.633 15.000  } }
  if { [string compare $sptype "a0v"] == 0 } { return { 14.838 15.000  }}
  if { [string compare $sptype "a5v"] == 0 } { return { 15.043 15.000 } }
  if { [string compare $sptype "f0v"] == 0 } { return { 15.315 15.000 } }
  if { [string compare $sptype "f5v"] == 0 } { return { 15.534 15.000 } }
  if { [string compare $sptype "g0v"] == 0 } { return { 15.728 15.000 } }
  if { [string compare $sptype "g5v"] == 0 } { return { 15.884 15.000 } }
  if { [string compare $sptype "k0v"] == 0 } { return { 16.057 15.000 } }
  if { [string compare $sptype "k5v"] == 0 } { return { 16.788 15.000 } }
  if { [string compare $sptype "m0v"] == 0 } { return { 17.032 15.000 } }
  if { [string compare $sptype "m5v"] == 0 } { return { 17.975 15.000 } }

  puts stderr "sptype_to_bminusr: bad sptype ..$sptype.. "

}



set star_id 0
set_foc_radec 0.0 0.0
set out_fid [open "foo.cat" "w"]

# first, do the optical chips in this block (chips 0-8)
for { set chip 0 } { $chip < 9 } { incr chip } {

  set row_list { 878 2634 878 2634 }
  set col_list { 878 878 2634 2634 }

  foreach quadrant { 0 1 2 3 } {

    if { $debug > 0 } {
      puts [format "next is chip %3d  quadrant %3d " $chip $quadrant]
    }

    set row [lindex $row_list $quadrant]
    set col [lindex $col_list $quadrant]
    if { $debug > 0 } {
      puts [format "         row %3d  col %3d \n" $row $col]
    }

    # figure out the RA, Dec center corresponding to this chip, row, col
    if { [chip_to_radec $chip $row $col ra dec] != 0 } {
      puts stderr "chip_to_radec fails on $chip $row $col "
      return 1
    }

    # use a canonical magnitude for all stars
    set mag 15.0

    # we loop over all spectral types of interest
    foreach sptype { o5v b57v a0v a5v f0v f5v g0v g5v k0v k5v m0v m5v } {

      set maglist [sptype_to_bminusr $sptype]
      set bmag [lindex $maglist 0]
      set rmag [lindex $maglist 1]
       
      set line [format "%5d x  %10.5f %10.5f xx x x %6.3f %6.3f x " \
                 $star_id $ra $dec $bmag $rmag ]
      puts $out_fid $line

      incr star_id
    }

    # now, we put down instances of SNe
    foreach sptype { sn1a_0_00 sn1a_0_05 sn1a_0_10 sn1a_0_15 } {

      set bmag $mag
      set rmag $mag
       
      set line [format "%5d %s  %10.5f %10.5f xx x x %6.3f %6.3f x " \
                 $star_id $sptype $ra $dec $bmag $rmag ]
      puts $out_fid $line

      incr star_id
    }


  }


}


# now, do the near-IR chips in this block (chips 9-17)
for { set chip 9 } { $chip < 18 } { incr chip } {

  set row_list { 512 1536 512 1536 }
  set col_list { 512 512 1536 1536 }

  foreach quadrant { 0 1 2 3 } {

    if { $debug > 0 } {
      puts [format "next is chip %3d  quadrant %3d " $chip $quadrant]
    }

    set row [lindex $row_list $quadrant]
    set col [lindex $col_list $quadrant]
    if { $debug > 0 } {
      puts [format "         row %3d  col %3d \n" $row $col]
    }

    # figure out the RA, Dec center corresponding to this chip, row, col
    if { [chip_to_radec $chip $row $col ra dec] != 0 } {
      puts stderr "chip_to_radec fails on $chip $row $col "
      return 1
    }

    # use a canonical magnitude for all stars
    set mag 15.0

    # we loop over all spectral types of interest
    foreach sptype { o5v b57v a0v a5v f0v f5v g0v g5v k0v k5v m0v m5v } {

      set maglist [sptype_to_bminusr $sptype]
      set bmag [lindex $maglist 0]
      set rmag [lindex $maglist 1]
       
      set line [format "%5d x  %10.5f %10.5f xx x x %6.3f %6.3f x " \
                 $star_id $ra $dec $bmag $rmag ]
      puts $out_fid $line

      incr star_id
    }

    # now, we put down instances of SNe
    foreach sptype { sn1a_0_00 sn1a_0_05 sn1a_0_10 sn1a_0_15 } {

      set bmag $mag
      set rmag $mag
       
      set line [format "%5d %s  %10.5f %10.5f xx x x %6.3f %6.3f x " \
                 $star_id $sptype $ra $dec $bmag $rmag ]
      puts $out_fid $line

      incr star_id
    }


  }

}


close $out_fid



