#!/usr/bin/perl
#
# This script performs a few simple tests to verify that the 
#   SNAP pipeline software has been installed properly.
#
# The script returns with code 
#          0       if all goes well (all tests pass)
#          1       if any test fails
#
# MWR 7/31/2004

use strict;
use POSIX;

# set to 1 to see messages as the script runs
my($debug) = 1;

# we'll return with this value
my($retcode) = 0;


if ($debug > 0) {
  printf "selftest.pl: running test of SNAP pipeline code .... \n"
}

# step 1: verify that we can run TCL by creating a tiny TCL command script
#         and then running the tclsh on it
#   
my($scriptfile) = "./selftest.tcl";
if (open(SCRIPTFILE, ">$scriptfile") == 0) {
  warn "selftest.pl: can't create script file $scriptfile? \n";
  exit(1);
}
printf SCRIPTFILE "exit 0 \n";
close(SCRIPTFILE);
my($cmd) = "tclsh $scriptfile";
if ($debug > 0) {
  printf "selftest.pl: about to test for tclsh: ..$cmd.. \n";
}
my($retcode) = system($cmd);
if ($retcode != 0) { 
  warn "selftest.pl: can't run tclsh -- is it installed? \n";
  exit($retcode);
}
unlink($scriptfile);
# if we get this far, then we can run tclsh, so we can use it as
#   our interpreter for the SNAP pipeline
my($interpreter) = "tclsh";



# step 2: verify that we can run wish (the graphical TCL shell) 
#         by creating a tiny TCL command script and then running 
#         the 'wish' on it
#   
my($scriptfile) = "./selftest.tcl";
if (open(SCRIPTFILE, ">$scriptfile") == 0) {
  warn "selftest.pl: can't create script file $scriptfile? \n";
  exit(1);
}
printf SCRIPTFILE "exit 0 \n";
close(SCRIPTFILE);
my($cmd) = "wish $scriptfile";
if ($debug > 0) {
  printf "selftest.pl: about to test for wish: ..$cmd.. \n";
}
my($retcode) = system($cmd);
if ($retcode != 0) { 
  warn "selftest.pl: can't run wish -- is it installed? \n";
  warn "selftest.pl: falling back on 'tclsh' for further tests \n";
} else {
  $interpreter = "wish";
}
unlink($scriptfile);

# note the interpreter we are going to use 
if ($debug > 0) {
  printf "selftest.pl: going to use $interpreter as interpreter \n";
}



# Step 3: try to run the SNAP pipeline
#         (it would be best to make sure param files hold the values
#          which will yield a quick test, but do that later ...)
my($scriptfile) = "./selftest.tcl";
my($script_output) = "./selftest.out";
if (open(SCRIPTFILE, ">$scriptfile") == 0) {
  warn "selftest.pl: can't create script file $scriptfile? \n";
  exit(1);
}
printf SCRIPTFILE "source snap_driver.tcl \n";
printf SCRIPTFILE "exit 0 \n";
close(SCRIPTFILE);
my($cmd) = "$interpreter $scriptfile >& $script_output";
if ($debug > 0) {
  printf "selftest.pl: cmd is ..$cmd.. \n";
}
if ($debug > -1) {
  printf "selftest.pl: about to run SNAP pipeline; this may take a minute .... \n";
  if ($interpreter eq "wish") {
    printf "selftest.pl: you may see a graphics window pop up .... \n";
  }
}
my($retcode) = system($cmd);
if ($retcode != 0) { 
  warn "selftest.pl: running pipeline fails \n";
  exit(1);
}
unlink($scriptfile);


# (we could compare output to some standard values ....)



# if we get here, all tests passed okay
if ($debug > 0) {
  printf "selftest.pl: all tests passed OK \n";
}

exit($retcode);


